summaryrefslogtreecommitdiffhomepage
path: root/Sources/cplusplus.cc
diff options
context:
space:
mode:
authorAmlal EL Mahrouss <amlal@softwarelabs.com>2024-06-01 18:22:01 +0200
committerAmlal EL Mahrouss <amlal@softwarelabs.com>2024-06-01 18:22:01 +0200
commit68b1c532bad643ca983b37e29d6621bd8b957d69 (patch)
tree7123ad9d05f00e73f6e234a5e7b4e50b8144bcd4 /Sources/cplusplus.cc
parentd0b25baeca4f807b43cff3bda2efd03fdff96728 (diff)
MHR-21: Amend commit, did some cleaning.
Signed-off-by: Amlal EL Mahrouss <amlal@softwarelabs.com>
Diffstat (limited to 'Sources/cplusplus.cc')
-rw-r--r--Sources/cplusplus.cc12
1 files changed, 6 insertions, 6 deletions
diff --git a/Sources/cplusplus.cc b/Sources/cplusplus.cc
index d03987c..72b654a 100644
--- a/Sources/cplusplus.cc
+++ b/Sources/cplusplus.cc
@@ -2,7 +2,7 @@
* ========================================================
*
* cplusplus
- * Copyright Amlal El Mahrouss, all rights reserved.
+ * Copyright SoftwareLabs, all rights reserved.
*
* ========================================================
*/
@@ -14,7 +14,7 @@
#define kPrintF printf
#define kSplashCxx() \
- kPrintF(kWhite "%s\n", "LightSpeed C++ Compiler, Copyright Amlal El Mahrouss.")
+ kPrintF(kWhite "%s\n", "LightSpeed C++ Compiler, Copyright SoftwareLabs.")
#include <Common/AsmKit/CPU/amd64.hpp>
#include <Common/ParserKit.hpp>
@@ -29,11 +29,11 @@
#define kOk 0
-/* Amlal El Mahrouss C++ driver */
+/* SoftwareLabs C++ driver */
/* This is part of MPCC C++ compiler. */
-/* (c) Amlal El Mahrouss */
+/* (c) SoftwareLabs */
-/// @author Amlal El Mahrouss (amlel)
+/// @author SoftwareLabs (amlel)
/// @file cc.cc
/// @brief Optimized C++ Compiler.
/// @todo Throw error for scoped inside scoped variables when they get referenced outside.
@@ -170,7 +170,7 @@ static bool kOnForLoop = false;
static bool kInBraces = false;
static size_t kBracesCount = 0UL;
/* @brief C++ compiler backend for Amlal El Mahrouss C++ */
class CompilerBackendCPlusPlus final : public ParserKit::CompilerBackend
{
public:
@@ -170,7 +170,7 @@ static bool kOnForLoop = false;
static bool kInBraces = false;
static size_t kBracesCount = 0UL;
-/* @brief C++ compiler backend for Amlal El Mahrouss C++ */
+/* @brief C++ compiler backend for SoftwareLabs C++ */
class CompilerBackendCPlusPlus final : public ParserKit::CompilerBackend
{